#
#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
#  All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions
#  are met:
#  1. Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#  SUCH DAMAGE.
#
# $Id$

global @Point {
   int x;
   int y;
}

global @Rect {
   int left;
   int bottom;
   int right;
   int top;
}

global %Font {
   int         height            ;
   int         width             ;
   int         style             ;
   int         pitch             ;
   double      direction         ;
   long        resolution        ;
   string      name              ;
   int         size              ;
   string      encoding          ;
   string      family            ;
   int         vector            ;
   int         ascent            ;
   int         descent           ;
   int         weight            ;
   int         maximalWidth      ;
   int         internalLeading   ;
   int         externalLeading   ;
   int         xDeviceRes        ;
   int         yDeviceRes        ;
   int         firstChar         ;
   int         lastChar          ;
   int         breakChar         ;
   int         defaultChar       ;
   U8          utf8_flags        ;
}

global @FillPattern U8[8];

global @NPoint {
   double x;
   double y;
}

global %PrinterInfo {
   string name;
   string device;
   Bool   defaultPrinter;
}
